==> pycharmPC-253.28294.306-EAP-CANDIDATE.zip: _sha512.py <==
# encoding: utf-8
# module _sha512
# from (built-in)
# by generator 1.147
# no doc
# no imports

# functions

def sha384(*args, **kwargs): # real signature unknown
    """ Return a new SHA-384 hash object; optionally initialized with a string. """
    pass

def sha512(*args, **kwargs): # real signature unknown
    """ Return a new SHA-512 hash object; optionally initialized with a string. """
    pass

# classes

class SHA384Type(object):
    # no doc
    def copy(self, *args, **kwargs): # real signature unknown
        """ Return a copy of the hash object. """
        pass

    def digest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a bytes object. """
        pass

    def hexdigest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a string of hexadecimal digits. """
        pass

    def update(self, *args, **kwargs): # real signature unknown
        """ Update this hash object's state with the provided string. """
        pass

    def __init__(self, *args, **kwargs): # real signature unknown
        pass

    block_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    digest_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    name = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default



class SHA512Type(object):
    # no doc
    def copy(self, *args, **kwargs): # real signature unknown
        """ Return a copy of the hash object. """
        pass

    def digest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a bytes object. """
        pass

    def hexdigest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a string of hexadecimal digits. """
        pass

    def update(self, *args, **kwargs): # real signature unknown
        """ Update this hash object's state with the provided string. """
        pass

    def __init__(self, *args, **kwargs): # real signature unknown
        pass

    block_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    digest_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    name = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default



class __loader__(object):
    """
    Meta path import for built-in modules.
    
        All methods are either class or static methods to avoid the need to
        instantiate the class.
    """
    @classmethod
    def create_module(cls, *args, **kwargs): # real signature unknown
        """ Create a built-in module """
        pass

    @classmethod
    def exec_module(cls, *args, **kwargs): # real signature unknown
        """ Exec a built-in module """
        pass

    @classmethod
    def find_module(cls, *args, **kwargs): # real signature unknown
        """
        Find the built-in module.
        
                If 'path' is ever specified then the search is considered a failure.
        
                This method is deprecated.  Use find_spec() instead.
        """
        pass

    @classmethod
    def find_spec(cls, *args, **kwargs): # real signature unknown
        pass

    @classmethod
    def get_code(cls, *args, **kwargs): # real signature unknown
        """ Return None as built-in modules do not have code objects. """
        pass

    @classmethod
    def get_source(cls, *args, **kwargs): # real signature unknown
        """ Return None as built-in modules do not have source code. """
        pass

    @classmethod
    def is_package(cls, *args, **kwargs): # real signature unknown
        """ Return False as built-in modules are never packages. """
        pass

    @classmethod
    def load_module(cls, *args, **kwargs): # real signature unknown
        """
        Load the specified module into sys.modules and return it.
        
            This method is deprecated.  Use loader.exec_module instead.
        """
        pass

    def module_repr(module): # reliably restored by inspect
        """
        Return repr for the module.
        
                The method is deprecated.  The import machinery does the job itself.
        """
        pass

    def __init__(self, *args, **kwargs): # real signature unknown
        pass

    __weakref__ = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default
    """list of weak references to the object (if defined)"""


    __dict__ = None # (!) real value is "mappingproxy({'__module__': '_frozen_importlib', '__doc__': 'Meta path import for built-in modules.\\n\\n    All methods are either class or static methods to avoid the need to\\n    instantiate the class.\\n\\n    ', 'module_repr': <staticmethod object at 0x0000020A854C6FC8>, 'find_spec': <classmethod object at 0x0000020A854CE048>, 'find_module': <classmethod object at 0x0000020A854CE088>, 'create_module': <classmethod object at 0x0000020A854CE0C8>, 'exec_module': <classmethod object at 0x0000020A854CE108>, 'get_code': <classmethod object at 0x0000020A854CE188>, 'get_source': <classmethod object at 0x0000020A854CE208>, 'is_package': <classmethod object at 0x0000020A854CE288>, 'load_module': <classmethod object at 0x0000020A854CE2C8>, '__dict__': <attribute '__dict__' of 'BuiltinImporter' objects>, '__weakref__': <attribute '__weakref__' of 'BuiltinImporter' objects>})"


# variables with complex values

__spec__ = None # (!) real value is "ModuleSpec(name='_sha512', loader=<class '_frozen_importlib.BuiltinImporter'>, origin='built-in')"

==> pycharmPC-253.29346.142-EAP-CANDIDATE.zip: _sha512.py <==
# encoding: utf-8
# module _sha512
# from /opt/teamcity-agent/system/.persistent_cache/pycharm/pythons4utils/python311/lib/python3.11/lib-dynload/_sha512.cpython-311-darwin.so
# by generator 1.147
# no doc
# no imports

# functions

def sha384(*args, **kwargs): # real signature unknown
    """ Return a new SHA-384 hash object; optionally initialized with a string. """
    pass

def sha512(*args, **kwargs): # real signature unknown
    """ Return a new SHA-512 hash object; optionally initialized with a string. """
    pass

# classes

class SHA384Type(object):
    # no doc
    def copy(self, *args, **kwargs): # real signature unknown
        """ Return a copy of the hash object. """
        pass

    def digest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a bytes object. """
        pass

    def hexdigest(self, *args, **kwargs): # real signature unknown
        """ Return the digest value as a string of hexadecimal digits. """
        pass

    def update(self, *args, **kwargs): # real signature unknown
        """ Update this hash object's state with the provided string. """
        pass

    def __init__(self, *args, **kwargs): # real signature unknown
        pass

    block_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    digest_size = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default

    name = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default



# variables with complex values

__loader__ = None # (!) real value is '<_frozen_importlib_external.ExtensionFileLoader object at 0x101535310>'

__spec__ = None # (!) real value is "ModuleSpec(name='_sha512', loader=<_frozen_importlib_external.ExtensionFileLoader object at 0x101535310>, origin='/opt/teamcity-agent/system/.persistent_cache/pycharm/pythons4utils/python311/lib/python3.11/lib-dynload/_sha512.cpython-311-darwin.so')"
